summaryrefslogtreecommitdiffstats
path: root/arts/tools/audiomanager.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'arts/tools/audiomanager.cpp')
-rw-r--r--arts/tools/audiomanager.cpp28
1 files changed, 14 insertions, 14 deletions
diff --git a/arts/tools/audiomanager.cpp b/arts/tools/audiomanager.cpp
index eff4f6f9..73debf80 100644
--- a/arts/tools/audiomanager.cpp
+++ b/arts/tools/audiomanager.cpp
@@ -37,7 +37,7 @@ using namespace std;
* as this is an 1:1 port of an old arts-0.3.4.1 artsbuilable visual widget,
* you'll see some porting artefacts, and it's not elegance itself ;)
*/
-Gui_AUDIO_MANAGER::Gui_AUDIO_MANAGER( TQWidget* parent, const char* name ) : Template_ArtsView( parent,name )
+Gui_AUDIO_MANAGER::Gui_AUDIO_MANAGER( TQWidget* tqparent, const char* name ) : Template_ArtsView( tqparent,name )
{
this->setCaption( i18n( "Audio Manager" ) );
this->setIcon( MainBarIcon( "artsaudiomanager", 32 ) );
@@ -72,14 +72,14 @@ void Gui_AUDIO_MANAGER::widgetDestroyed(TQWidget *widget)
}
#endif
-void Gui_AUDIO_MANAGER::setParent(TQWidget *parent, TQBoxLayout * /*layout*/)
+void Gui_AUDIO_MANAGER::setParent(TQWidget *tqparent, TQBoxLayout * /*tqlayout*/)
{
/************************************************************************
* From Gui_INSTRUMENT_MAPPER:
*
* I am still not sure wether this kind of putting yourself into a parent
* widget (with own layout etc.) is a good idea (there may not even be
* a singe call to setParent, because there is no parent).
*
* But the "how to write aRts widgets"-stuff will need some experiments,
* so lets try that method...
@@ -90,12 +90,12 @@ void Gui_AUDIO_MANAGER::setParent(TQWidget *parent, TQBoxLayout * /*layout*/)
* else would be appropriate. Check that. FIXME
************************************************************************/
- TQVBoxLayout *mainlayout = new TQVBoxLayout(parent);
- /*TQHBoxLayout *contentslayout = new TQHBoxLayout;*/
+ TQVBoxLayout *maintqlayout = new TQVBoxLayout(tqparent);
+ /*TQHBoxLayout *contentstqlayout = new TQHBoxLayout;*/
// list
- listview = new KListView(parent);
+ listview = new KListView(tqparent);
listview->addColumn(i18n("Title"),175);
listview->addColumn(i18n("Type"),50);
@@ -106,11 +106,11 @@ void Gui_AUDIO_MANAGER::setParent(TQWidget *parent, TQBoxLayout * /*layout*/)
TQObject::connect(listview,TQT_SIGNAL(executed(TQListViewItem *)),proxy,
TQT_SLOT(edit(TQListViewItem *)));
- mainlayout->addWidget(listview);
+ maintqlayout->addWidget(listview);
- mainlayout->activate();
- //mainlayout->freeze();
- ParentWidget = parent;
+ maintqlayout->activate();
+ //maintqlayout->freeze();
+ ParentWidget = tqparent;
}
void Gui_AUDIO_MANAGER::tick()
@@ -178,8 +178,8 @@ void GuiAudioManagerProxy::edit(TQListViewItem *item)
gim->edit(item);
}
-AudioManagerItem::AudioManagerItem(TQListView *parent, TQString a,
- TQString b, TQString c, long ID) :TQListViewItem(parent,a,b,c)
+AudioManagerItem::AudioManagerItem(TQListView *tqparent, TQString a,
+ TQString b, TQString c, long ID) :TQListViewItem(tqparent,a,b,c)
{
_ID = ID;
}
@@ -72,14 +72,14 @@ void Gui_AUDIO_MANAGER::widgetDestroyed(TQWidget *widget)
* From Gui_INSTRUMENT_MAPPER:
*
- * I am still not sure wether this kind of putting yourself into a parent
- * widget (with own layout etc.) is a good idea (there may not even be
- * a singe call to setParent, because there is no parent).
+ * I am still not sure wether this kind of putting yourself into a tqparent
+ * widget (with own tqlayout etc.) is a good idea (there may not even be
+ * a singe call to setParent, because there is no tqparent).
*
* But the "how to write aRts widgets"-stuff will need some experiments,